/*
 * ============================================================================
 * Licensed Materials - Property of IBM
 *  WebSphere sMash
 *
 * (C) Copyright IBM Corp. 2007  All Rights Reserved.
 *
 * US Government Users Restricted Rights - Use, duplication or disclosure
 * restricted by GSA ADP Schedule Contract with IBM Corp.
 * ============================================================================
 */
package zero.resource.utils;

import zero.resource.utils.GUtils;
import zero.resource.Member;
import zero.resource.exceptions.DataFormatException;
import org.apache.abdera.model.Entry;
import org.apache.abdera.model.Content.Type;

public class GUtilsImpl extends GUtils {
    
    public String getMemberAsXOXO(Member member) {
        try {
            def sw = new StringWriter()
            def builder = new groovy.xml.MarkupBuilder(sw)
            builder.ul (class: member.type.typeName)  {
                builder.li {
                    member.type.fields.each{ field_name, field_spec ->
                        
                        if ( !(field_name in ['id', 'updated']) && member[field_name] != null )  {
                            builder.ul (compact: 'compact') {
                                builder.dl {
                                    builder.dt field_name
                                    builder.dd field_spec.convertFrom(member[field_name])
                                }
                            }
                        }
                    }
                }
            }
            return sw.toString()
            
        } catch (Exception e) {
            throw new DataFormatException("exception occurred while generating XOXO from Member: ${e}")
        }

    }
    
    public Map getXOXOAsMap(Entry entry) {
        if (entry.getContentType()!= Type.XHTML) {
             throw new DataFormatException('atom:content must be xhtml in xoxo format')
        }
        def content = entry.getContent()
        def ul = new XmlParser(false, false).parseText(content)
        Map map = [:]
        ul.li.ul.each{ 
            map[it.dl.dt.text()] = it.dl.dd.text()
        }

        return map
    }
}